Theme configuration
-------------------

.. tabularcolumns:: |p{3cm}|p{6cm}|p{1.5cm}|p{1.8cm}|p{2cm}|
.. list-table::
   :header-rows: 1

   * - Property
     - Description
     - I18n
     - Required
     - Unique
   
   * - Color
     - Color of active menu and vertical line on left side. Each page can have its own color vertical line on left side.
     - no
     - yes
     - no

.. note::

   Property *Color* use in :ref:`classic <Available_themes>` theme only